Image Reduction — MSUMastro toolbox 0.1 documentation

# Image Reduction

This module contains one (yes, only one) function. It trims the overscan from an image. There is no plan to develop image reduction routines in this package because the Astropy ccdproc package will contain that functionality.

This module contains functions useful for reducing CCD images.

`msumastro.reduction.reduction.` `trim`(hdu)

  Trim the overscan region from an image.

  Parameters: | hdu : astropy.io.fits.HDU FITS HDU for the image from which overscan is to be trimmed.
  Returns: | astropy.io.fits.HDU The modified HDU

  Notes

  This function does NOT do any overscan correction to the image. It trims the image and nothing else.